@@ -50,7 +50,8 @@ GOLD_DB_NAME = f"cortex_databricks_gold_{ENVIRONMENT}"
 def __verify_parameters(function):
     def wrapper(*args, **kwargs):
         insert_modes_avalables = ["append", "upsert"]
-        if kwargs.get("insert_mode") in insert_modes_avalables:
+        insert_mode = kwargs.get("insert_mode", "append")
+        if  insert_mode in insert_modes_avalables:
              return function(*args, **kwargs)
         else:
             raise ValueError(
@@ -412,7 +413,7 @@ def landing_to_bronze(
     data_type: str,
     data_pack_name,
     dataset_name,
-    insert_mode="append",
+    insert_mode=None,
     schema_path_or_struct_schema=None,
     partition_columns=None,
     spark=None,
@@ -469,6 +470,9 @@ def landing_to_bronze(
     if os.getenv("ENVIRONMENT") != "LOCAL":
         spark.sql(f"USE CATALOG {catalog_name}")
 
+    if insert_mode is None:
+        insert_mode = "append"
+
     df = read_data(
         spark,
         data_input_path=data_input_path,
@@ -546,6 +550,8 @@ def bronze_to_silver(
             dataset_name=dataset_name,
             input_table_name=input_table_name,
         )
+    if insert_mode is None:
+        insert_mode = "append"
 
     df = read_table(spark, db_name=input_db_name, table_name=input_table_name)
     df = apply_processing_function(
@@ -613,6 +619,8 @@ def silver_to_gold(
             dataset_name=dataset_name,
             input_table_name=input_table_name,
         )
+    if insert_mode is None:
+        insert_mode = "append"
 
     df = read_table(spark, db_name=input_db_name, table_name=input_table_name)
     df = apply_processing_function(
